@@ -631,3 +631,99 @@ def createDirectoriesNewVersion(version, project_name, old_versions):
             return error[0], False
     
     return "OK", True
+
+def modifyFilesNewAPI(version,group,name,http_verb,type_api,url,availability,project_name):
+    """
+        Función encargada de modificar archivos para nueva api en django
+
+        Función encargada de modificar los archivos necesarios para crear una nueva api
+        en el proyecto django.
+
+        Parámetros:
+            version         [String]    Versión donde se creará la API
+            group           [String]    Grupo donde se creará la API
+            name            [String]    Nombre de la API
+            http_verb       [String]    HTTP Verb de la API (POST, PUT, DELETE)
+            type_api        [String]    Tipo de la API (MODEL, OPEN)
+            url             [String]    URL donde se podrá acceder a la API
+            availability    [String]    Disponibilidad de la API (public, private)
+            project_name    [String]    Nombre del proyecto
+        Retorno:
+            message,result  [Tuple]     Mensaje[String] y result[Boolean]
+    """
+    errors = []
+    primary_package = "springlabs_django"
+    
+    # Obtener variables dependientes del HTTP_VERB
+    if http_verb == "POST":
+        base_views = "post_views_"
+        base_serializers = "post_serializers_"
+    elif http_verb == "PUT":
+        base_views = "put_views_"
+        base_serializers = "put_serializers_"
+    elif http_verb == "DELETE":
+        base_views = "delete_views_"
+        base_serializers = "delete_serializers_"
+    
+    # Obtener variables dependientes del TYPE_API
+    if type_api=="open":
+        base_views = base_views+"open.py"
+        base_serializers = base_serializers+"open.py"
+    elif type_api=="model":
+        base_views = base_views+"model.py"
+        base_serializers = base_serializers+"model.py"
+    
+    # Obtener variables dependientes del AVAILABILITY
+    if availability=="public":
+        general_urls = "public_urls.py"
+    elif availability=="private":
+        general_urls = "private_urls.py"
+    
+    base_views_py = f"/core/new_api/api/{base_views}"
+    base_serializers_py = f"/core/new_api/api/{base_serializers}"
+    # Obtiene contenido de /core/new_api/api/{base_views}
+    try:
+        template_views_py = pkgutil.get_data(primary_package, base_views_py).decode('utf-8')
+        template_views_py = template_views_py.replace("API_NAME", name.capitalize())
+    except:
+        message = f"Ocurrió un error interno en /core/new_api/api/{base_views}"
+        errors.append([message, True])
+    
+    # Obtiene contenido de /core/new_api/api/{base_serializers}
+    try:
+        template_serializers_py = pkgutil.get_data(primary_package, base_serializers_py).decode('utf-8')
+        template_serializers_py = template_serializers_py.replace("API_NAME", name.capitalize())
+    except:
+        message = f"Ocurrió un error interno en /core/new_api/api/{base_serializers}"
+        errors.append([message, True])
+    
+    # Escribe en archivo views.py
+    path = f"api/v{version}/{group}/views.py"
+    message, result = appendContent(path=path,
+        content=template_views_py)
+    if result == False:
+        errors.append([message, True])
+
+    # Escribe en archivo serializers.py
+    path = f"api/v{version}/{group}/serializers.py"
+    message, result = appendContent(path=path,
+        content=template_serializers_py)
+    if result == False:
+        errors.append([message, True])
+
+    # Escribe en urls public/private
+    views_name = f"{name.capitalize()}{http_verb.capitalize()}"
+    path = f"api/v{version}/{general_urls}"
+    find = f"# {group.upper()} URLS (Managed by SPRINGLABS_DJANGO)"
+    content = f"    url(r'^{url}/$', {group.lower()}_views.{views_name}),"
+    message, result = appendContent(path=path,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
+    for error in errors:
+        if error[1] == True:
+            return error[0], False
+
+    return "OK", True
\ No newline at end of file
